@@ -58,7 +58,9 @@ test_runner = DiscoverRunner(verbosity=1)
 
 failures = test_runner.run_tests([
     'djangoldp.tests.tests_ldp_model',
-    'djangoldp.tests.tests_save',
+    'djangoldp.tests.tests_model_serializer',
+    'djangoldp.tests.tests_ldp_viewset',
+    'djangoldp.tests.tests_post',
     'djangoldp.tests.tests_user_permissions',
     'djangoldp.tests.tests_guardian',
     'djangoldp.tests.tests_anonymous_permissions',
@@ -70,8 +72,10 @@ failures = test_runner.run_tests([
     'djangoldp.tests.tests_pagination',
     'djangoldp.tests.tests_inbox',
     'djangoldp.tests.tests_backlinks_service',
+    'djangoldp.tests.tests_cache',
     'djangoldp_i18n.tests.tests_get',
-    'djangoldp_i18n.tests.tests_post'
+    'djangoldp_i18n.tests.tests_post',
+    'djangoldp_i18n.tests.tests_cache'
 ])
 if failures:
     sys.exit(failures)
